==> rutorrent-3.9.tar.gz: ruTorrent-3.9/plugins/rss/lang/el.js <==
﻿/*
 * PLUGIN RSS
 *
 * Greek language file.
 *
 * Author: Chris Kanatas (ckanatas@gmail.com)
 */

 theUILang.addRSS			= "Προσθήκη τροφοδοσίας RSS";
 theUILang.feedURL			= "URL";
 theUILang.alias			= "Προσαρμ. όνομα";
 theUILang.rssAuto			= "Αυτόματη λήψη αντικειμένων που δημοσιεύονται στην τροφοδοσία";
 theUILang.allFeeds			= "Όλες οι τροφοδοσίες";
 theUILang.incorrectURL 		= "Παρακαλώ ορίστε σωστό URL της τροφοδοσίας."
 theUILang.cantFetchRSS 		= "Σφάλμα φόρτωσης τροφοδοσίας.";
 theUILang.rssAlreadyExist		= "Η τροφοδοσία υπάρχει ήδη.";
 theUILang.rssDontExist 		= "Η τροφοδοσία δεν υπάρχει.";
 theUILang.rssCantLoadTorrent		= "Σφάλμα φόρτωσης torrent.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Έχει ήδη φορτωθεί";
 theUILang.rssMenuLoad			= "Φόρτωση";
 theUILang.rssMenuOpen			= "Άνοιγμα στο πρόγραμμα περιήγησης";
 theUILang.rssMenuClearHistory		= "Εκκαθάριση Ιστορικού";
 theUILang.rssMenuAddToFilter		= "Προσθήκη στα αγαπημένα";
 theUILang.rssMenuManager		= "Διαχειριστής RSS";
 theUILang.rssMenuRefresh		= "Ανανέωση τροφοδοσίας";
 theUILang.rssMenuDisable		= "Απενεργοποίηση τροφοδοσίας";
 theUILang.rssMenuEnable		= "Ενεργοποίηση τροφοδοσίας";
 theUILang.rssMenuEdit			= "Επεξεργασία τροφοδοσίας";
 theUILang.rssMenuDelete		= "Διαγραφή τροφοδοσίας";
 theUILang.rssDeletePrompt		= "Θέλετε πραγματικά να διαγράψετε την επιλεγμένη τροφοδοσία;";
 theUILang.rssNewFilter 		= "Νέο φίλτρο";
 theUILang.rssFilter			= "Φίλτρο";
 theUILang.rssAddFilter 		= "Προσθήκη";
 theUILang.rssDelFilter 		= "Διαγραφή";
 theUILang.rssCheckFilter		= "Δοκιμή";
 theUILang.rssFiltersLegend		= "Ρυθμίσεις φίλτρων";
 theUILang.rssIncorrectFilter		= "Το φίλτρο είναι εσφαλμένο.";
 theUILang.foundedByFilter		= "Ταιριάζουν";
 theUILang.rssExclude			= "Εξαίρεση";
 theUILang.rssStatusError		= "Σφάλμα φόρτωσης";
 theUILang.rssFeeds			= "Τροφοδοσίες";
 theUILang.rssCheckTitle		= "Έλεγχος πεδίου φίλτρου";
 theUILang.rssCheckDescription		= "Έλεγχος πεδίου περιγραφής";
 theUILang.rssCheckLink 		= "Έλεγχος πεδίου συνδέσμου";
 theUILang.rssMinInterval		= "Χρονικό διάστημα";
 theUILang.rssIntervalAlways		= "(ταίριασμα πάντα)";
 theUILang.rssIntervalOnce		= "(ταίριασμα μια φορά)";
 theUILang.rssInterval12h		= "12 ώρες";
 theUILang.rssInterval1d		= "1 ημέρα";
 theUILang.rssInterval2d		= "2 ημέρες";
 theUILang.rssInterval3d		= "3 ημέρες";
 theUILang.rssInterval4d		= "4 ημέρες";
 theUILang.rssInterval6d		= "6 ημέρες";
 theUILang.rssInterval1w		= "1 εβδομάδα";
 theUILang.rssInterval2w		= "2 εβδομάδες";
 theUILang.rssInterval3w		= "3 εβδομάδες";
 theUILang.rssInterval1m		= "1 μήνας";
 theUILang.rssClearFilter		= "Επαναφορά";
 theUILang.rssMarkAs			= "Σημείωση ως";
 theUILang.rssAsLoaded			= "φορτωμένο";
 theUILang.rssAsUnloaded		= "μη φορτωμένο";
 theUILang.addRSSGroup			= "Προσθήκη ομάδας RSS";
 theUILang.editRSSGroup 		= "Επεξεργασία ομάδας RSS";
 theUILang.addRSSGroupContent		= "Περιεχόμενο";
 theUILang.rssMenuGroupDisable		= "Απενεργοποίηση ομάδας";
 theUILang.rssMenuGroupRefresh		= "Ενημέρωση ομάδας";
 theUILang.rssMenuGroupEnable		= "Ενεργοποίηση ομάδας";
 theUILang.rssMenuGroupEdit		= "Επεξεργασία ομάδας";
 theUILang.rssMenuGroupDelete		= "Διαγραφή ομάδας";
 theUILang.rssMenuGroupContentsDelete	= "Διαγραφή περιεχομένων";
 theUILang.rssDeleteGroupPrompt 	= "Θέλετε πραγματικά να διαγράψετε την επιλεγμένη ομάδα;";
 theUILang.rssDeleteGroupContentsPrompt = "Θέλετε πραγματικά να διαγράψετε την επιλεγμένη ομάδα με όλα τα περιεχόμενα;";
 theUILang.rssAllFiters 		= "Όλα τα φίλτρα";
 theUILang.rssUpdateInterval 		= "Μεσοδιάστημα ανανέωσης";
 theUILang.Directories			= "Φάκελοι";
 theUILang.Labels			= "Ετικέτες";

thePlugins.get("rss").langLoaded();

==> rutorrent-5.2.9.tar.gz: ruTorrent-5.2.9/plugins/rss/lang/el.js <==
﻿/*
 * PLUGIN RSS
 *
 * Greek language file.
 *
 * Author: Chris Kanatas (ckanatas@gmail.com)
 */

 theUILang.addRSS			= "Προσθήκη τροφοδοσίας RSS";
 theUILang.feedURL			= "URL";
 theUILang.alias			= "Προσαρμ. όνομα";
 theUILang.rssAuto			= "Αυτόματη λήψη αντικειμένων που δημοσιεύονται στην τροφοδοσία";
 theUILang.allFeeds			= "Όλες οι τροφοδοσίες";
 theUILang.incorrectURL			= "Παρακαλώ ορίστε σωστό URL της τροφοδοσίας.";
 theUILang.cantFetchRSS			= "Σφάλμα φόρτωσης τροφοδοσίας.";
 theUILang.rssAlreadyExist		= "Η τροφοδοσία υπάρχει ήδη.";
 theUILang.rssDontExist			= "Η τροφοδοσία δεν υπάρχει.";
 theUILang.rssCantLoadTorrent		= "Σφάλμα φόρτωσης torrent.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Έχει ήδη φορτωθεί";
 theUILang.rssMenuLoad			= "Φόρτωση";
 theUILang.rssMenuOpen			= "Άνοιγμα στο πρόγραμμα περιήγησης";
 theUILang.rssMenuClearHistory		= "Εκκαθάριση Ιστορικού";
 theUILang.rssMenuAddToFilter		= "Προσθήκη στα αγαπημένα";
 theUILang.rssMenuManager		= "Διαχειριστής RSS";
 theUILang.rssMenuRefresh		= "Ανανέωση τροφοδοσίας";
 theUILang.rssMenuDisable		= "Απενεργοποίηση τροφοδοσίας";
 theUILang.rssMenuEnable		= "Ενεργοποίηση τροφοδοσίας";
 theUILang.rssMenuEdit			= "Επεξεργασία τροφοδοσίας";
 theUILang.rssMenuDelete		= "Διαγραφή τροφοδοσίας";
 theUILang.rssDeletePrompt		= "Θέλετε πραγματικά να διαγράψετε την επιλεγμένη τροφοδοσία;";
 theUILang.rssNewFilter			= "Νέο φίλτρο";
 theUILang.rssFilter			= "Φίλτρο";
 theUILang.rssAddFilter			= "Προσθήκη";
 theUILang.rssDelFilter			= "Διαγραφή";
 theUILang.rssCheckFilter		= "Δοκιμή";
 theUILang.rssFiltersLegend		= "Ρυθμίσεις φίλτρων";
 theUILang.rssIncorrectFilter		= "Το φίλτρο είναι εσφαλμένο.";
 theUILang.foundedByFilter		= "Ταιριάζουν";
 theUILang.rssExclude			= "Εξαίρεση";
 theUILang.rssStatusError		= "Σφάλμα φόρτωσης";
 theUILang.rssFeeds			= "Τροφοδοσίες";
 theUILang.rssCheckTitle		= "Έλεγχος πεδίου φίλτρου";
 theUILang.rssCheckDescription		= "Έλεγχος πεδίου περιγραφής";
 theUILang.rssCheckLink			= "Έλεγχος πεδίου συνδέσμου";
 theUILang.rssMinInterval		= "Χρονικό διάστημα";
 theUILang.rssIntervalAlways		= "(ταίριασμα πάντα)";
 theUILang.rssIntervalOnce		= "(ταίριασμα μια φορά)";
 theUILang.rssInterval12h		= "12 ώρες";
 theUILang.rssInterval1d		= "1 ημέρα";
 theUILang.rssInterval2d		= "2 ημέρες";
 theUILang.rssInterval3d		= "3 ημέρες";
 theUILang.rssInterval4d		= "4 ημέρες";
 theUILang.rssInterval6d		= "6 ημέρες";
 theUILang.rssInterval1w		= "1 εβδομάδα";
 theUILang.rssInterval2w		= "2 εβδομάδες";
 theUILang.rssInterval3w		= "3 εβδομάδες";
 theUILang.rssInterval1m		= "1 μήνας";
 theUILang.rssClearFilter		= "Επαναφορά";
 theUILang.rssMarkAs			= "Σημείωση ως";
 theUILang.rssAsLoaded			= "φορτωμένο";
 theUILang.rssAsUnloaded		= "μη φορτωμένο";
 theUILang.addRSSGroup			= "Προσθήκη ομάδας RSS";
 theUILang.editRSSGroup			= "Επεξεργασία ομάδας RSS";
 theUILang.addRSSGroupContent		= "Περιεχόμενο";
 theUILang.rssMenuGroupDisable		= "Απενεργοποίηση ομάδας";
 theUILang.rssMenuGroupRefresh		= "Ενημέρωση ομάδας";
 theUILang.rssMenuGroupEnable		= "Ενεργοποίηση ομάδας";
 theUILang.rssMenuGroupEdit		= "Επεξεργασία ομάδας";
 theUILang.rssMenuGroupDelete		= "Διαγραφή ομάδας";
 theUILang.rssMenuGroupContentsDelete	= "Διαγραφή περιεχομένων";
 theUILang.rssDeleteGroupPrompt		= "Θέλετε πραγματικά να διαγράψετε την επιλεγμένη ομάδα;";
 theUILang.rssDeleteGroupContentsPrompt	= "Θέλετε πραγματικά να διαγράψετε την επιλεγμένη ομάδα με όλα τα περιεχόμενα;";
 theUILang.rssAllFiters			= "Όλα τα φίλτρα";
 theUILang.rssUpdateInterval		= "Μεσοδιάστημα ανανέωσης";
 theUILang.rssShowErrorsDelayed		= "Καθυστέρηση της ειδοποίησης για σφάλματα RSS μέχρι η καρτέλα καταγραφής σφαλμάτων ή η τροφοδοσία RSS να είναι ορατά";
 theUILang.Directories			= "Φάκελοι";
 theUILang.Labels			= "Ετικέτες";
 theUILang.rssPatternExample		= "Regular Expression Example";

thePlugins.get("rss").langLoaded();
